<template>
  <el-dialog
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="80px"
      class="l-mes"
    >
      <el-form-item label="请求地址" prop="url">
        <el-input v-model="dataForm.url" placeholder="请求地址"></el-input>
      </el-form-item>
      <el-form-item label="方法名称" prop="procedureName">
        <el-input
          v-model="dataForm.procedureName"
          placeholder="方法名称"
        ></el-input>
      </el-form-item>
      <el-form-item label="是否禁用" prop="state">
        <el-switch v-model="dataForm.state"> </el-switch>
      </el-form-item>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
        >确定</el-button
      >
    </span>
  </el-dialog>
</template>

<script>
import { getObj, addObj, putObj } from '@/api/admin/ifsconfiguration'

export default {
  components: {},
  data() {
    return {
      visible: false,
      dataForm: {
        id: 0,
        url: '',
        procedureName: '',
        state: false
      },
      dataRule: {
        url: [{ required: true, message: '请求地址不能为空', trigger: 'blur' }],
        procedureName: [
          { required: true, message: '方法名称不能为空', trigger: 'blur' }
        ]
      },
      isSubmit: false
    }
  },
  methods: {
    init(id) {
      this.dataForm.id = id || 0
      this.visible = true
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getObj(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
          })
        }
      })
    },
    // 表单提交
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          if (this.dataForm.id) {
            putObj(this.dataForm)
              .then((data) => {
                this.$message.success('修改成功')
                this.visible = false
                this.isSubmit = false
                this.$emit('refreshDataList')
              })
              .catch(() => {
                this.isSubmit = false
              })
          } else {
            addObj(this.dataForm)
              .then((data) => {
                this.$message.success('新增成功')
                this.visible = false
                this.isSubmit = false
                this.$emit('refreshDataList')
              })
              .catch(() => {
                this.isSubmit = false
              })
          }
        } else {
          this.isSubmit = false
        }
      })
    }
  }
}
</script>
